@@ -6,5 +6,5 @@ plot.pcaCoDa <- function(x, y, ...){
 	beschx <- if(x$method == "robust") "PC1 (clr-robust)" else "PC1 (clr-standard)"
 	beschy <- if(x$method == "robust") "PC2 (clr-robust)" else "PC2 (clr-standard)"
 #	biplot(x$princompOutputClr, xlab=beschx, ylab=beschy)
-	biplot(x$princompOutputClr, xlab=beschx, ylab=beschy)
+	biplot(x$princompOutputClr, xlab=beschx, ylab=beschy, ...)
 }
\ No newline at end of file
